@@ -21,7 +21,9 @@
 
 import unittest
 
-from fedmsg.tests.test_text import Base
+from fedmsg.tests.test_meta import Base
+
+from fedmsg_meta_fedora_infrastructure.tests.pkgdb import *
 
 class TestFASUserCreate(Base):
     expected_title = "fas.user.create (unsigned)"
